@@ -7,10 +7,10 @@ import pathlib
 import ctypes
 import comtypes
 from comtypes import client
-from . import _dia
+from . import _dia, cvconst
 
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 
 
 _SCRIPT_DIR = pathlib.Path(__file__).resolve().parent
